#!/bin/sh

echo
echo "No. of vars in global.inc.php:"
echo "------------------------------"
echo -n "non unique:" ; cat global.inc.php | cut -f 1 -d " " | grep "^\\$" | grep -v "^\/" | sort | wc -l
cat global.inc.php | cut -f 1 -d " " | grep "^\\$" | grep -v "^\/" | sort > non-unique.php
echo -n "unique:    " ; cat global.inc.php | cut -f 1 -d " " | grep "^\\$" | grep -v "^\/" | sort | uniq | wc -l
cat global.inc.php | cut -f 1 -d " " | grep "^\\$" | grep -v "^\/" | sort | uniq > unique.php
echo
echo "Duplicates:"
echo "-----------"
diff non-unique.php unique.php | grep "^<" | cut -f 2 -d " "
rm non-unique.php unique.php
echo
